# NASA EARTHDATA GLOSSARY

Many of the terms used by NASA Earth Observing System Data and Information System (EOSDIS)
are defined in their Earth Observation Data Basics Glossary.

[GLOSSARY](https://www.earthdata.nasa.gov/learn/earth-observation-data-basics/glossary#ed-glossary-c)

We also give some simple definitions for commonly used terms in this documentation below.

**Collection**: a set of data products or files for the same release of that product,
    data generated during an experiment or campaign.

**concept-id**: a unique identifier for a collection, granule, service or tool.  Concept-id can be used to search for datasets or granules using `earthaccess`.

**Granule**: the smallest aggregation of data.  It could be an individual scene or swath acquired at a given timestep.  You can think of granules as files.
